/*
Copyright © 2022 Matthieu Derasse <git@derasse.fr>
*/
package cmd

import (
	"git.dev.m-and-m.ovh/mderasse/gouick/helpers/api_types"
	"github.com/spf13/cobra"

	log "github.com/sirupsen/logrus"
)

// readmeCmd represents the readme command.
var readmeCmd = &cobra.Command{
	Use:   "readme",
	Short: "Generate Readme",
	Run:   runGenerateReadme,
}

func init() {
	generateCmd.AddCommand(readmeCmd)
}

// runGenerateReadmeAction will generate the Readme for the current project.
func runGenerateReadme(cmd *cobra.Command, args []string) {
	log.Debugf("Starting command GenerateReadme")
	currentPath, config, err := loadProjectAndConfig()
	if err != nil {
		return
	}

	apiType, err := api_types.GetAPIType(config.ProjectType)
	if err != nil {
		log.Error("Impossible to load that API Type generator")
		return
	}

	// Generate ReadMe
	log.Info("Generating ReadMe")
	err = apiType.GenerateReadme(currentPath, config)
	if err != nil {
		log.Errorf("Fail to generate ReadMe. The following error happen: %s", err.Error())
		return
	}
}
