package go_swagger

import (
	"os"

	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"

	log "github.com/sirupsen/logrus"
)

// CheckInitialize will do preliminary check before initializing a new project.
func (a APIType) CheckInitialize() error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	// Get current path
	log.Debug("Getting current location")

	currentPath, err := os.Getwd()
	if err != nil {
		log.Errorf("Fail to get current path. The following error happen: %s", err.Error())
		return errors.Trace(err)
	}

	// Check if we are in a go project already
	log.Debug("Checking if we are in a Go Project")

	isGoProject, err := helpers.IsGoProject(currentPath)
	if err != nil {
		log.Errorf("Fail to check if we are in a Go Project. The following error happen: %s", err.Error())
		return errors.Trace(err)
	}

	if isGoProject {
		log.Error("We already are in a golang project directory")
		return errors.NotValidf("We already are in a golang project directory")
	}

	return nil
}
