package go_swagger

import (
	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

type stdTemplateStruct struct {
	categorizedProcess
	Config *models.Config
}

type categorizedProcess struct {
	APIs    []*models.Process
	Crons   []*models.Process
	Workers []*models.Process
}

// getStdTemplate will generate the "basic" struct we will provide to a template.
func (a APIType) getStdTemplate(path string, config *models.Config) (*stdTemplateStruct, error) {

	data := stdTemplateStruct{
		Config: config,
	}

	processes, err := a.getProcesses(path)
	if err != nil {
		log.Error("Fail to list processes")
		return nil, errors.Trace(err)
	}

	for _, process := range processes {
		switch process.Type {
		case models.ProcessType_API:
			data.APIs = append(data.APIs, process)
		case models.ProcessType_CRON:
			data.Crons = append(data.Crons, process)
		case models.ProcessType_WORKER:
			data.Workers = append(data.Workers, process)
		}
	}

	return &data, nil
}
