package go_swagger

import (
	"path/filepath"

	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"

	log "github.com/sirupsen/logrus"
)

var standardDirectories = []string{
	"api",
	"chart",
	"cmd",
	"deployments",
	"models",
	"internal",
	"internal/api",
	"internal/helper",
	"internal/transform",
	"pkg",
	"restapi",
	"restapi/operations",
	"testdata",
}

// createDirectories will create all skeleton directories for the project.
func (a APIType) createDirectories(path string) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	for _, directory := range standardDirectories {

		log.Debugf("Will create directory %s", directory)

		fullPath := filepath.Join(path, directory)

		created, err := helpers.CheckAndCreateDir(fullPath)
		if err != nil {
			log.Errorf("Failed to create directory %s", directory)
			return errors.Trace(err)
		}
		if !created {
			log.Debugf("Skipping directory %s", directory)
		}
	}

	return nil
}
