package go_swagger

import (
	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"
	"git.dev.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

// CreateProjectSkeleton will generate all the files needed to start a new project.
func (a APIType) CreateProjectSkeleton(path string, config *models.Config) error {
	log.Debugf("Starting %s  - %s", a.GetName(), helpers.GetCurrentFuncName())

	err := a.createDirectories(path)
	if err != nil {
		log.Error("Fail to create project directories")
		return errors.Trace(err)
	}

	// Generate api yaml files
	err = a.createDefaultAPIYamls(path, config)
	if err != nil {
		log.Error("Fail to generate API Yaml files")
		return errors.Trace(err)
	}

	// init Go Module
	err = a.initializeGoModule(path, config)
	if err != nil {
		log.Error("Fail to initialize Go Module")
		return errors.Trace(err)
	}

	// Launch Go Swagger
	err = a.executeGoSwagger(path)
	if err != nil {
		log.Error("Fail to Execute Go Swagger")
		return errors.Trace(err)
	}

	// Delete api yaml temporary file
	err = a.deleteTempApiYaml(path)
	if err != nil {
		log.Error("Fail to delete api yaml temporary file")
		return errors.Trace(err)
	}

	// Launch Go Swagger
	err = a.downloadGoDeps(path)
	if err != nil {
		log.Error("Fail to download go dependencies")
		return errors.Trace(err)
	}

	return nil
}
