package go_swagger

import (
	"os"
	"path/filepath"

	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"
	"git.dev.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

// GenerateAPI will generate api files such as server, controllers, test, ....
func (a APIType) GenerateAPI(path string, config *models.Config) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	// delete file that need to be regenerated
	err := a.deleteRegeneratedFiles(path)
	if err != nil {
		log.Error("Fail to delete Files that will be regenerated by Go Swagger")
		return errors.Trace(err)
	}

	err = a.createDirectories(path)
	if err != nil {
		log.Error("Fail to create project directories")
		return errors.Trace(err)
	}

	// Launch Go Swagger
	err = a.executeGoSwagger(path)
	if err != nil {
		log.Error("Fail to Execute Go Swagger")
		return errors.Trace(err)
	}

	// No use atm
	// Generate files from spec
	// err = a.generateFromSpec(path)
	// if err != nil {
	// 	log.Error("Fail to generate files from spec")
	//	return errors.Trace(err)
	// }

	// Delete api yaml temporary file
	err = a.deleteTempApiYaml(path)
	if err != nil {
		log.Error("Fail to delete api yaml temporary file")
		return errors.Trace(err)
	}

	return nil
}

// deleteRegeneratedFiles will delete files that will be regenerated by go swagger.
func (a APIType) deleteRegeneratedFiles(path string) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	for _, file := range regeneratedFiles {
		tempFilePath := filepath.Join(path, file)

		exist, err := helpers.FileExists(tempFilePath, true)
		if err != nil {
			return errors.Trace(err)
		}

		if !exist {
			log.Debug("File/Directory doesn't exist already")
			return nil
		}

		err = os.RemoveAll(tempFilePath)
		if err != nil {
			log.Errorf("fail to delete file/dir in %s", tempFilePath)
			return errors.Trace(err)
		}
	}

	return nil
}

// // generateFromSpec will read the swagger spec and create cmd server, handlers, test ...
// func (a APIType) generateFromSpec(path string) error {
// 	log.Debugf("Starting %s  - %s", a.GetName(), helpers.GetCurrentFuncName())

// 	tempFilePath := filepath.Join(path, mergeYamlFileName)
// 	specData, err := spec.NewSpec(tempFilePath)
// 	if err != nil {
// 		return errors.Trace(err)
// 	}
// 	fmt.Printf("%#v", specData.GetOperationGroups())

// 	return nil
// }
