package go_swagger

import (
	"os"
	"os/exec"

	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"
	"git.dev.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

// initializeGoModule will launch a go mod init.
func (a APIType) initializeGoModule(path string, config *models.Config) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	if err := os.Chdir(path); err != nil {
		log.Error("Fail to move to the path")
		return errors.Trace(err)
	}

	modulePath := ""
	if config.ModulePath != nil {
		modulePath = *config.ModulePath
	}

	cmd := exec.Command("go", "mod", "init", modulePath)
	output, err := cmd.CombinedOutput()
	if err != nil {
		log.Errorf("fail to execute go mod init %s", modulePath)
		return errors.Trace(err)
	}

	log.Debugf("go mod init %s returned the following output: %s", modulePath, string(output))

	return nil
}

// downloadGoDeps will execute go get ./... in the give repository.
func (a APIType) downloadGoDeps(path string) error {
	log.Debugf("Starting %s  - %s", a.GetName(), helpers.GetCurrentFuncName())

	// making sure that we are in the project directory
	if err := os.Chdir(path); err != nil {
		log.Error("Fail to move to the path")
		return errors.Trace(err)
	}

	// execute go get to download missing package
	cmd := exec.Command("go", "get", "./...")
	output, err := cmd.CombinedOutput()
	if err != nil {
		log.Error("fail to execute 'go get ./...'")
		return errors.Trace(err)
	}

	log.Debugf("'go get ./...' returned the following output: %s", string(output))

	return nil
}
