package go_swagger

import (
	"fmt"
	"path/filepath"
	"strings"

	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"
	"git.dev.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

// getProcesses will read cmd directory and guess the app processes.
func (a APIType) getProcesses(path string) ([]*models.Process, error) {
	log.Debugf("Starting %s  - %s", a.GetName(), helpers.GetCurrentFuncName())

	cmdPath := filepath.Join(path, "cmd")
	cmdDirectories, err := filepath.Glob(filepath.Join(cmdPath, "*"))
	if err != nil {
		log.Error("Fail to list cmd directory")
		return nil, errors.Trace(err)
	}

	processes := make([]*models.Process, 0)

	for _, absDir := range cmdDirectories {
		dir := strings.TrimPrefix(absDir, fmt.Sprintf("%s%c", cmdPath, filepath.Separator))

		// if we have a suffix -server or -api we are on an API.
		// if we have a prefix worker- we are on a worker.
		// if we have a prefix cron- we are on a cron.
		if strings.HasSuffix(dir, "-server") || strings.HasSuffix(dir, "-api") {
			processes = append(processes, &models.Process{
				Binary: dir,
				Name:   dir,
				Type:   models.ProcessType_API,
			})
		} else if strings.HasPrefix(dir, "worker-") {
			processes = append(processes, &models.Process{
				Binary: dir,
				Name:   strings.TrimPrefix(dir, "worker-"),
				Type:   models.ProcessType_WORKER,
			})
		} else if strings.HasPrefix(dir, "cron-") {
			processes = append(processes, &models.Process{
				Binary: dir,
				Name:   strings.TrimPrefix(dir, "cron-"),
				Type:   models.ProcessType_CRON,
			})
		}
	}

	return processes, nil
}
