package go_swagger

import (
	"os"
	"path/filepath"

	"github.com/juju/errors"

	"git.dev.m-and-m.ovh/mderasse/gouick/helpers"
	"git.dev.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

// createDefaultAPIYamls will generate the main api yaml file based on the given config.
// Launched only at project init.
func (a APIType) createDefaultAPIYamls(path string, config *models.Config) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	type templateFileStruct struct {
		savePath     string
		templatePath string
	}

	templateFileList := []templateFileStruct{
		{
			savePath:     filepath.Join(path, "api.yaml"),
			templatePath: filepath.Join(templateDirectory, "custom/api.yaml.tmpl"),
		},
		{
			savePath:     filepath.Join(path, "api/001-general.yaml"),
			templatePath: filepath.Join(templateDirectory, "custom/api/001-general.yaml.tmpl"),
		},
		{
			savePath:     filepath.Join(path, "api/001-monitoring.yaml"),
			templatePath: filepath.Join(templateDirectory, "custom/api/002-monitoring.yaml.tmpl"),
		},
	}

	data, err := a.getStdTemplate(path, config)
	if err != nil {
		log.Error("Fail to generate standard template variable")
		return errors.Trace(err)
	}

	for _, templateFile := range templateFileList {

		err := helpers.WriteTemplate(templateFile.templatePath, templateFile.savePath, data)
		if err != nil {
			return errors.Trace(err)
		}
	}

	return nil
}

// deleteTempApiYaml will delete the temporary yaml api file generated by go-swagger.
func (a APIType) deleteTempApiYaml(path string) error {
	log.Debugf("Starting %s  - %s", a.GetName(), helpers.GetCurrentFuncName())

	tempFilePath := filepath.Join(path, mergeYamlFileName)

	exist, err := helpers.FileExists(tempFilePath, false)
	if err != nil {
		return errors.Trace(err)
	}

	if !exist {
		log.Debug("File doesn't exist already")
		return nil
	}

	err = os.Remove(tempFilePath)
	if err != nil {
		log.Errorf("fail to delete file in %s", tempFilePath)
		return errors.Trace(err)
	}

	return nil
}
